@@ -1,4 +1,4 @@
-from wcd_geo_db.modules.client import NestedClient
+from px_client_builder import NestedClient
 
 from .formatter import FormatterClient
 
