@@ -1,14 +1,13 @@
-from typing import Any, Callable, Dict, List, Optional, Sequence, Set, Tuple, Type
-from functools import cached_property, reduce
+from typing import Any, Callable, Dict, Optional, Sequence, Tuple, TYPE_CHECKING
+from functools import cached_property
 from px_client_builder import NestedClient
-from wcd_geo_db.const import DivisionLevel
 from wcd_geo_db.modules.code_seeker.query import CodeSeekSeq
 
-from ...bank.dtos import DivisionDTO
-# from ..query.geometry import Area
+from ...bank.dtos import DivisionDTO, DivisionTranslationDTO
 from ..dtos import AddressDefinitionDTO, FormattedAddressDTO
-# from ..db import Division
-# from ..query import DivisionsQuerySet
+
+if TYPE_CHECKING:
+    from ...bank import BankClient
 
 
 __all__ = 'FormatterClient',
@@ -24,14 +23,13 @@ class FormatterClient(NestedClient):
 
         self._bank_lookup = bank_lookup
 
-    @cached_property
-    def bank(self):
-        return self._bank_lookup(self)
+    bank: 'BankClient' = cached_property(lambda x: x._bank_lookup(x))
 
     def _make_formatted_address(
         self,
         definition: AddressDefinitionDTO,
-        divisions_map: Dict[int, DivisionDTO] = {}
+        divisions_map: Dict[int, DivisionDTO] = {},
+        translations_map: Dict[int, DivisionTranslationDTO] = {},
     ) -> Optional[FormattedAddressDTO]:
         path = definition.get('divisions_path')
 
@@ -39,9 +37,9 @@ class FormatterClient(NestedClient):
             return None
 
         divisions = [
-            divisions_map[id]
+            translations_map.get(id, None) or divisions_map[id]
             for id in path
-            if id in divisions_map
+            if id in translations_map or id in divisions_map
         ]
 
         return FormattedAddressDTO(
@@ -71,7 +69,9 @@ class FormatterClient(NestedClient):
         divisions = []
 
         for definition in definitions:
-            path = (definition.get('divisions_path') or ())
+            # FIXME: Made an adequate normalization that wouldn't
+            # mutate initial structure.
+            path = definition['divisions_path'] = list(definition.get('divisions_path') or ())
 
             for i, division in enumerate(path):
                 if division is None:
@@ -81,23 +81,34 @@ class FormatterClient(NestedClient):
                     division_ids.add(division)
                 elif isinstance(division, DivisionDTO):
                     divisions.append(division)
-                    # FIXME: Made an adequate normalization that wouldn't
-                    # mutate initial structure.
+                    division_ids.add(division.id)
                     path[i] = division.id
                 else:
                     raise TypeError(
                         f'Wrong division in path: {type(division)}, {repr(division)}.'
                     )
 
-        if len(division_ids) > 0:
-            divisions += list(self.bank.divisions.get(ids=division_ids))
+        # FIXME: A little bit inefficient.
+        # There must be a way to fallback to division names if no translation
+        # here in on query.
+        translations = self.bank.divisions.get_translations(
+            ids=division_ids,
+            language=language, fallback_languages=fallback_languages
+        )
+        translations_map = {t.entity_id: t for t in translations}
+
+        no_translated_ids = division_ids - translations_map.keys()
+
+        if len(no_translated_ids) > 0:
+            divisions += list(self.bank.divisions.get(ids=no_translated_ids))
 
         divisions_map = {d.id: d for d in divisions}
 
         return [
             self._make_formatted_address(
                 definition,
-                divisions_map=divisions_map
+                divisions_map=divisions_map,
+                translations_map=translations_map
             )
             for definition in definitions
         ]
