@@ -11,6 +11,8 @@ QT = TypeVar('QT', bound='SearchQuerySet')
 class SearchQueryParam(TypedDict):
     language: str
     query: str
+    min_rank: Optional[float]
+    use_simple_search: Optional[bool]
 
 
 class SearchQuerySet(QuerySet):
