@@ -2,4 +2,4 @@ from .seeker import CodeSeeker
 
 __all__ = 'ISO3166_SEEKER',
 
-ISO3166_SEEKER = CodeSeeker('ISO3166')
+ISO3166_SEEKER = CodeSeeker(name='ISO3166')
