@@ -30,9 +30,13 @@ class CodeSeeker:
         self.set_field_name = s_default(self, 'set_field_name', set_field_name)
 
     def to_representation(self, value):
+        """Function that resolves stored value to a python value type."""
         return value
 
     def to_value(self, representation):
+        """Function that resolves python value type to value that will be
+        stored.
+        """
         return representation
 
     def Q_set(self, value: Any, field_name: Optional[str] = None, lookup: str = 'exact') -> models.Q:
@@ -47,10 +51,10 @@ class CodeSeeker:
         })
 
     def eq(self, a: Any, b: Any) -> bool:
-        return a == b
+        return self.to_value(a) == self.to_value(b)
 
     def ge(self, a: Any, b: Any) -> bool:
-        return a > b
+        return self.to_value(a) > self.to_value(b)
 
     def __hash__(self) -> int:
         return self.name.__hash__()
